@@ -37,7 +37,9 @@ from aleph.sdk.client.services.crn import Crn
 from aleph.sdk.client.services.dns import DNS
 from aleph.sdk.client.services.instance import Instance
 from aleph.sdk.client.services.port_forwarder import PortForwarder
+from aleph.sdk.client.services.pricing import Pricing
 from aleph.sdk.client.services.scheduler import Scheduler
+from aleph.sdk.client.services.voucher import Vouchers
 
 from ..conf import settings
 from ..exceptions import (
@@ -48,8 +50,15 @@ from ..exceptions import (
     RemovedMessageError,
     ResourceNotFoundError,
 )
-from ..query.filters import MessageFilter, PostFilter
-from ..query.responses import MessagesResponse, Post, PostsResponse, PriceResponse
+from ..query.filters import BalanceFilter, MessageFilter, PostFilter
+from ..query.responses import (
+    BalanceResponse,
+    CreditsHistoryResponse,
+    MessagesResponse,
+    Post,
+    PostsResponse,
+    PriceResponse,
+)
 from ..types import GenericMessage, StoredContent
 from ..utils import (
     Writable,
@@ -135,6 +144,8 @@ class AlephHttpClient(AlephClient):
         self.crn = Crn(self)
         self.scheduler = Scheduler(self)
         self.instance = Instance(self)
+        self.pricing = Pricing(self)
+        self.voucher = Vouchers(self)
 
         return self
 
@@ -520,7 +531,10 @@ class AlephHttpClient(AlephClient):
             try:
                 resp.raise_for_status()
                 response_json = await resp.json()
+                cost = response_json.get("cost", None)
+
                 return PriceResponse(
+                    cost=cost,
                     required_tokens=response_json["required_tokens"],
                     payment_type=response_json["payment_type"],
                 )
@@ -532,8 +546,12 @@ class AlephHttpClient(AlephClient):
             try:
                 resp.raise_for_status()
                 response_json = await resp.json()
+                cost = response_json.get("cost", None)
+                required_tokens = response_json["required_tokens"]
+
                 return PriceResponse(
-                    required_tokens=response_json["required_tokens"],
+                    required_tokens=required_tokens,
+                    cost=cost,
                     payment_type=response_json["payment_type"],
                 )
             except aiohttp.ClientResponseError as e:
@@ -564,7 +582,7 @@ class AlephHttpClient(AlephClient):
             message, status = await self.get_message(
                 item_hash=ItemHash(item_hash), with_status=True
             )
-            if status != MessageStatus.PROCESSED:
+            if status not in [MessageStatus.PROCESSED, MessageStatus.REMOVING]:
                 resp = f"Invalid message status: {status}"
             elif message.type != MessageType.store:
                 resp = f"Invalid message type: {message.type}"
@@ -592,3 +610,37 @@ class AlephHttpClient(AlephClient):
             if result
             else StoredContent(error=resp, filename=None, hash=None, url=None)
         )
+
+    async def get_credit_history(
+        self,
+        address: str,
+        page_size: int = 200,
+        page: int = 1,
+    ) -> CreditsHistoryResponse:
+        """Return List of credits history for a specific addresses"""
+
+        params = {
+            "page": str(page),
+            "pagination": str(page_size),
+        }
+
+        async with self.http_session.get(
+            f"/api/v0/addresses/{address}/credit_history", params=params
+        ) as resp:
+            resp.raise_for_status()
+            result = await resp.json()
+            return CreditsHistoryResponse.model_validate(result)
+
+    async def get_balances(
+        self,
+        address: str,
+        filter: Optional[BalanceFilter] = None,
+    ) -> BalanceResponse:
+
+        async with self.http_session.get(
+            f"/api/v0/addresses/{address}/balance",
+            params=filter.as_http_params() if filter else None,
+        ) as resp:
+            resp.raise_for_status()
+            result = await resp.json()
+            return BalanceResponse.model_validate(result)
